# -*- eval: (blacken-mode) -*-
import logging
import numpy as np
from numpy.testing import assert_allclose

import usadelndsoc
import usadelndsoc.solver

usadelndsoc.logger.setLevel(logging.DEBUG)


def basic_setup(terminals=False, nx=25, ny=5):
    Delta = np.zeros((4, 4))
    Delta[:2, 2:] = np.eye(2)
    Delta[2:, :2] = np.eye(2)

    s = usadelndsoc.solver.Solver(nx=nx, ny=ny)
    s.Omega[...] = Delta
    s.alpha = 0.0
    s.Lx = 10
    s.Ly = 10
    s.U[:, :, 1, :, :] = np.eye(4)

    if terminals:
        s.mask[0, :] = usadelndsoc.solver.MASK_TERMINAL
        s.mask[-1, :] = usadelndsoc.solver.MASK_TERMINAL

    return s


# s.solve(omega=150, maxiter=300, preconditioner="none")


def test_solve_dos():
    s = basic_setup()
    E = np.linspace(-3, 3, 101) + 0.001j
    res = s.solve_many(omega=-1j * E)
    g = res.G[:, 10, 2, 0, 0]
    g_an = -1j * E / np.sqrt(1 - E**2)
    assert_allclose(g, g_an, rtol=1e-4)
